@@ -341,7 +341,7 @@ class Spec:
         fields = cls().cls().__dict__
         for key in fields.keys():
             val = fields[key]
-            if isinstance(val, Variable) and not isinstance(val, InVariable) and val.input:
+            if isinstance(val, Variable) and not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and val.input:
                 inputs.append(val)
 
         return inputs
@@ -363,7 +363,7 @@ class Spec:
         fields = cls().cls().__dict__
         for key in fields.keys():
             val = fields[key]
-            if isinstance(val, Variable) and not isinstance(val, OutVariable) and val.output:
+            if isinstance(val, Variable) and not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and val.output:
                 outputs.append(val)
 
         return outputs
@@ -385,7 +385,7 @@ class Spec:
         fields = cls().cls().__dict__
         for key in fields.keys():
             val = fields[key]
-            if (isinstance(val, Variable) or isinstance(val, Credentials)) and not isinstance(val, OptVariable) and val.option:
+            if (isinstance(val, Variable) or isinstance(val, Credentials))  and not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and val.option:
                 options.append(val)
 
         return options
